package com.ocity.api.auth;

import jakarta.servlet.http.Cookie;
import jakarta.servlet.http.HttpServletRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.util.WebUtils;

import java.util.Optional;

@Component
public class ApiKeyRetriever {

    private static final String AUTH_COOKIE_NAME = "apiKey";
    private static final String REQUEST_TOKEN_HEADER = "Authorization";
    private static final String REQUEST_TOKEN_HEADER_PATTERN = "Bearer ";

    public Optional<String> execute(HttpServletRequest request) {
        final Optional<Cookie> cookieApiKey = getApiKeyFromCookie(request);

        return cookieApiKey.isPresent()
                ? cookieApiKey.map(Cookie::getValue)
                : getApiKeyFromHeader(request);
    }

    private Optional<Cookie> getApiKeyFromCookie(HttpServletRequest request) {
        return Optional.ofNullable(WebUtils.getCookie(request, AUTH_COOKIE_NAME));
    }

    private Optional<String> getApiKeyFromHeader(HttpServletRequest request) {
        return getRequestAuthTokenHeader(request)
                .map(header -> header.substring(REQUEST_TOKEN_HEADER_PATTERN.length()));
    }

    private Optional<String> getRequestAuthTokenHeader(HttpServletRequest request) {
        return Optional.ofNullable(request.getHeader(REQUEST_TOKEN_HEADER));
    }
}
