package com.ocity.api.core.application.heritage;

import com.ocity.api.core.application.heritage.dto.HeritageItemDTO;
import com.ocity.api.core.application.heritage.dto.in.CategoriesDTO;
import com.ocity.api.core.application.heritage.dto.in.HeritageFormat;
import com.ocity.api.core.application.heritage.dto.out.schemaorg.SchemaOrgHeritageItemDTOMapper;
import com.ocity.api.core.application.heritage.dto.out.une.UNEHeritageItemDTOMapper;
import com.ocity.api.core.domain.heritage.HeritageItem;
import com.ocity.api.core.domain.heritage.HeritageRepository;
import com.ocity.api.core.domain.locations.StateId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Objects;

@Component
public class FindDataByStateId {

    private final TypesMapper typesMapper;
    private final HeritageRepository heritageRepository;
    private final UNEHeritageItemDTOMapper uneHeritageItemDTOMapper;
    private final SchemaOrgHeritageItemDTOMapper schemaOrgHeritageItemDTOMapper;

    @Autowired
    public FindDataByStateId(TypesMapper typesMapper,
                             HeritageRepository heritageRepository,
                             UNEHeritageItemDTOMapper uneHeritageItemDTOMapper,
                             SchemaOrgHeritageItemDTOMapper schemaOrgHeritageItemDTOMapper) {
        this.typesMapper = typesMapper;
        this.heritageRepository = heritageRepository;
        this.uneHeritageItemDTOMapper = uneHeritageItemDTOMapper;
        this.schemaOrgHeritageItemDTOMapper = schemaOrgHeritageItemDTOMapper;
    }

    public List<HeritageItemDTO> execute(Integer stateId, CategoriesDTO categoriesDTO, HeritageFormat heritageFormat) {
        return heritageRepository.findByStateId(new StateId(stateId), typesMapper.map(categoriesDTO), heritageFormat).stream()
                .map(heritageItem -> map(heritageItem, heritageFormat))
                .filter(Objects::nonNull)
                .toList();
    }

    private HeritageItemDTO map(HeritageItem heritageItem, HeritageFormat heritageFormat) {
        return switch (heritageFormat) {
            case UNE -> uneHeritageItemDTOMapper.map(heritageItem);
            case SCHEMA_ORG -> schemaOrgHeritageItemDTOMapper.map(heritageItem);
        };
    }
}
