package com.ocity.api.core.application.heritage.dto.out.schemaorg;

import com.ocity.api.core.domain.heritage.Description;
import com.ocity.api.core.domain.heritage.DescriptionLanguage;
import com.ocity.api.core.domain.heritage.DescriptionText;
import com.ocity.api.core.domain.heritage.Extras;
import com.ocity.api.core.domain.heritage.HeritageItem;
import com.ocity.api.core.domain.heritage.ImageUrl;
import com.ocity.api.core.domain.heritage.Links;
import com.ocity.api.core.domain.heritage.TouristType;
import com.ocity.api.core.domain.heritage.UrlFriendly;
import com.ocity.api.core.domain.heritage.schemaorg.SchemaOrgType;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

@Component
public class SchemaOrgHeritageItemDTOMapper {

    private static final List<SchemaOrgType> BLACK_LIST = List.of(
            SchemaOrgType.EVENT,
            SchemaOrgType.LAND_FORM,
            SchemaOrgType.BODY_OF_WATER,
            SchemaOrgType.PLACE,
            SchemaOrgType.TOURIST_ATTRACTION,
            SchemaOrgType.VOLCANO
    );

    private static final List<SchemaOrgType> TOURIST_TYPE_BLACK_LIST = List.of(
            SchemaOrgType.EVENT
    );

    private static final List<SchemaOrgType> EXTRAS_BLACK_LIST = List.of(
            SchemaOrgType.PLACE,
            SchemaOrgType.EVENT,
            SchemaOrgType.VOLCANO,
            SchemaOrgType.BODY_OF_WATER,
            SchemaOrgType.LAND_FORM,
            SchemaOrgType.TOURIST_ATTRACTION,
            SchemaOrgType.MUSEUM
    );

    public SchemaOrgHeritageItemDTO map(HeritageItem heritageItem) {
        if (heritageItem.type().isEmpty()) return null;

        SchemaOrgHeritageItemDTO dto = new SchemaOrgHeritageItemDTO();

        dto.id = heritageItem.id().value().toString();
        dto.name = heritageItem.name().value();
        dto.description = mapDescriptionDTO(heritageItem.description());
        dto.imageUrl = heritageItem.imageUrl().map(ImageUrl::value).orElse(null);
        dto.type = heritageItem.type().stream().filter(Objects::nonNull).map(SchemaOrgType.class::cast).map(SchemaOrgType::getName).toList();
        dto.url = heritageItem.links().map(Links::urlFriendly).map(UrlFriendly::value).orElse(null);

        if (TOURIST_TYPE_BLACK_LIST.stream().noneMatch(type -> heritageItem.type().contains(type))) {
            dto.touristType = heritageItem.touristType().stream().filter(Objects::nonNull).map(TouristType::getName).toList(); //TODO set null if empty?
        }

        if (EXTRAS_BLACK_LIST.stream().noneMatch(type -> heritageItem.type().contains(type))) {
            dto.extras = mapExtras(heritageItem.extras()); //TODO delete?
        }

        if (BLACK_LIST.stream().noneMatch(type -> heritageItem.type().contains(type))) {
            dto.address = mapAddress(heritageItem);
            dto.geo = mapGeo(heritageItem);
        }

        return dto;
    }

    private GeoDTO mapGeo(HeritageItem heritageItem) {
        GeoDTO dto = new GeoDTO();

        dto.latitude = heritageItem.latitude().value().toString();
        dto.longitude = heritageItem.longitude().value().toString();

        return dto;
    }

    private AddressDTO mapAddress(HeritageItem heritageItem) {
        AddressDTO addressDTO = new AddressDTO();
        addressDTO.addressCountry = heritageItem.addressCountry().value();
        addressDTO.addressLocality = heritageItem.addressLocality().value();

        return addressDTO;
    }

    private List<DescriptionDTO> mapDescriptionDTO(List<Description> descriptionList) {
        return descriptionList.stream()
                .map(this::buildDescriptionDTO)
                .toList();
    }

    private DescriptionDTO buildDescriptionDTO(Description description) {
        DescriptionDTO dto = new DescriptionDTO();

        dto.language = description.language().map(DescriptionLanguage::value).orElse(null);
        dto.value = description.text().map(DescriptionText::value).orElse(StringUtils.EMPTY); //TODO empty string or null DTO?

        return dto;
    }

    private String mapExtras(Extras extras) {
        if (extras.value().isEmpty()) return null;

        return extras.value().stream()
                .map(StringUtils::upperCase)
                .collect(Collectors.joining(", "));
    }
}
