package com.ocity.api.core.application.heritage.dto.out.une;

import com.ocity.api.core.domain.heritage.About;
import com.ocity.api.core.domain.heritage.AboutLanguage;
import com.ocity.api.core.domain.heritage.AboutText;
import com.ocity.api.core.domain.heritage.Description;
import com.ocity.api.core.domain.heritage.DescriptionLanguage;
import com.ocity.api.core.domain.heritage.DescriptionText;
import com.ocity.api.core.domain.heritage.Extras;
import com.ocity.api.core.domain.heritage.HeritageItem;
import com.ocity.api.core.domain.heritage.ImageUrl;
import com.ocity.api.core.domain.heritage.Link;
import com.ocity.api.core.domain.heritage.Links;
import com.ocity.api.core.domain.heritage.TouristType;
import com.ocity.api.core.domain.heritage.une.UNEType;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.stream.Collectors;

@Component
public class UNEHeritageItemDTOMapper {

    public UNEHeritageItemDTO map(HeritageItem heritageItem) {
        UNEHeritageItemDTO dto = new UNEHeritageItemDTO();

        dto.id = heritageItem.id().value().toString();
        dto.name = heritageItem.name().value();
        dto.addressCountry = heritageItem.addressCountry().value();
        dto.addressLocality = heritageItem.addressLocality().value();
        dto.latitude = heritageItem.latitude().value().toString();
        dto.longitude = heritageItem.longitude().value().toString();
        dto.description = mapDescriptionDTO(heritageItem.description());
        dto.imageUrl = heritageItem.imageUrl().map(ImageUrl::value).orElse(null);
        dto.type = heritageItem.type().stream().filter(Objects::nonNull).map(UNEType.class::cast).map(UNEType::getName).toList();
        dto.touristType = heritageItem.touristType().stream().filter(Objects::nonNull).map(TouristType::getName).toList(); //TODO set null if empty?
        dto.links = heritageItem.links().map(this::mapUrlDTO).orElse(null);
        dto.about = mapAboutDTO(heritageItem.about());
        dto.extras = mapExtras(heritageItem.extras());

        return dto;
    }

    private List<DescriptionDTO> mapDescriptionDTO(List<Description> descriptionList) {
        return descriptionList.stream()
                .map(description -> new DescriptionDTO(
                        description.language().map(DescriptionLanguage::value).orElse(null),
                        description.text().map(DescriptionText::value).orElse(null)))
                .toList();
    }

    private UrlDTO mapUrlDTO(Links links) {
        return new UrlDTO(links.urlFriendly().value(), mapLinkDTO(links.links()));

    }

    private List<LinkDTO> mapLinkDTO(Optional<List<Link>> mayBeLinks) {
        return mayBeLinks
                .map(links -> links.stream()
                        .map(link -> new LinkDTO(link.descriptionText().value(), link.url().value()))
                        .toList())
                .orElse(null);
    }

    private List<AboutDTO> mapAboutDTO(List<About> aboutList) {
        return aboutList.stream()
                .map(about -> new AboutDTO(
                        about.language().map(AboutLanguage::value).orElse(null),
                        about.text().map(AboutText::value).orElse(null)))
                .toList();
    }

    private String mapExtras(Extras extras) {
        if (extras.value().isEmpty()) return null;

        return extras.value().stream()
                .map(StringUtils::upperCase)
                .collect(Collectors.joining(", "));
    }
}
