package com.ocity.api.core.application.locations;

import com.ocity.api.core.application.locations.dto.out.CountryDTO;
import com.ocity.api.core.application.locations.dto.out.CountryDTOMapper;
import com.ocity.api.core.domain.locations.LocationsRepository;
import com.ocity.api.core.domain.locations.SubregionId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Comparator;
import java.util.List;

@Component
public class FindCountriesBySubregionId {

    private final LocationsRepository locationsRepository;
    private final CountryDTOMapper countryDTOMapper;

    @Autowired
    public FindCountriesBySubregionId(LocationsRepository locationsRepository, CountryDTOMapper countryDTOMapper) {
        this.locationsRepository = locationsRepository;
        this.countryDTOMapper = countryDTOMapper;
    }

    public List<CountryDTO> execute(Integer subregionId) {
        return locationsRepository.findCountriesBySubregionId(new SubregionId(subregionId)).stream()
                .map(countryDTOMapper::map)
                .sorted(Comparator.comparing(countryDTO -> countryDTO.name))
                .toList();
    }
}
