package com.ocity.api.core.application.locations;

import com.ocity.api.core.application.locations.dto.out.SubregionDTO;
import com.ocity.api.core.application.locations.dto.out.SubregionDTOMapper;
import com.ocity.api.core.domain.locations.LocationsRepository;
import com.ocity.api.core.domain.locations.RegionId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Comparator;
import java.util.List;

@Component
public class FindSubregionsByRegionId {

    private final LocationsRepository locationsRepository;
    private final SubregionDTOMapper subregionDTOMapper;

    @Autowired
    public FindSubregionsByRegionId(LocationsRepository locationsRepository, SubregionDTOMapper subregionDTOMapper) {
        this.locationsRepository = locationsRepository;
        this.subregionDTOMapper = subregionDTOMapper;
    }

    public List<SubregionDTO> execute(Integer regionId) {
        return locationsRepository.findSubregionsByRegionId(new RegionId(regionId)).stream()
                .map(subregionDTOMapper::map)
                .sorted(Comparator.comparing(subregionDTO -> subregionDTO.name))
                .toList();
    }
}
