package com.ocity.api.core.domain.heritage;

import org.apache.commons.lang3.Validate;

import java.util.List;
import java.util.Optional;

public class HeritageItem {

    private final Id id;
    private final Name name;
    private final AddressCountry addressCountry;
    private final AddressLocality addressLocality;
    private final Latitude latitude;
    private final Longitude longitude;
    private final List<Description> description;
    private final ImageUrl imageUrl;
    private final List<FormatType> type;
    private final List<TouristType> touristType;
    private final Links links;
    private final List<About> about;
    private final Extras extras;

    public HeritageItem(Id id,
                        Name name,
                        AddressCountry addressCountry,
                        AddressLocality addressLocality,
                        Latitude latitude,
                        Longitude longitude,
                        List<Description> description,
                        ImageUrl imageUrl,
                        List<FormatType> type,
                        List<TouristType> touristType,
                        Links links,
                        List<About> about,
                        Extras extras) {
        Validate.notNull(id, "Id cannot be null");
        Validate.notNull(name, "Name cannot be null");
        Validate.notNull(addressCountry, "AddressCountry cannot be null");
        Validate.notNull(addressLocality, "AddressLocality cannot be null");
        Validate.notNull(latitude, "Latitude cannot be null");
        Validate.notNull(longitude, "Longitude cannot be null");
        Validate.notNull(description, "Description cannot be null");
        Validate.notNull(type, "Type cannot be null");
        Validate.notNull(touristType, "TouristType cannot be null");
        Validate.notNull(links, "Links cannot be null");
        Validate.notNull(about, "About cannot be null");
        Validate.notNull(extras, "Extras cannot be null");
        this.id = id;
        this.name = name;
        this.addressCountry = addressCountry;
        this.addressLocality = addressLocality;
        this.latitude = latitude;
        this.longitude = longitude;
        this.description = description;
        this.imageUrl = imageUrl;
        this.type = type;
        this.touristType = touristType;
        this.links = links;
        this.about = about;
        this.extras = extras;
    }

    public Id id() {
        return id;
    }

    public Name name() {
        return name;
    }

    public AddressCountry addressCountry() {
        return addressCountry;
    }

    public AddressLocality addressLocality() {
        return addressLocality;
    }

    public Latitude latitude() {
        return latitude;
    }

    public Longitude longitude() {
        return longitude;
    }

    public List<Description> description() {
        return description;
    }

    public Optional<ImageUrl> imageUrl() {
        return Optional.ofNullable(imageUrl);
    }

    public List<FormatType> type() {
        return type;
    }

    public List<TouristType> touristType() {
        return touristType;
    }

    public Optional<Links> links() {
        return Optional.ofNullable(links);
    }

    public List<About> about() {
        return about;
    }

    public Extras extras() {
        return extras;
    }
}
