package com.ocity.api.core.domain.heritage;

import java.util.EnumMap;
import java.util.List;

import static com.ocity.api.core.domain.heritage.TouristType.ASTRONOMY_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.BIRDING_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.CULTURAL_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.ECOTOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.EVENTS_AND_FESTIVALS_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.FAMILY_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.FILM_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.FOOD_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.GEOLOGICAL_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.HERITAGE_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.INDUSTRIAL_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.MEMORIAL_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.NATURE_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.RELIGIOUS_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.RURAL_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.SPORTS_TOURISM;
import static com.ocity.api.core.domain.heritage.TouristType.URBAN_TOURISM;

public class TouristTypeMapper {

    private static final EnumMap<Subtype, List<TouristType>> SUBTYPE_TOURIST_TYPES_MAP = new EnumMap<>(Subtype.class);

    static {
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.ARCHAELOGICAL_ELEMENTS, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.NATURAL_ELEMENT, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.OBJECTS_OF_ANTHROPOLOGICAL_OR_ETHNOLOGICAL_INTEREST, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.WORKS_OF_ART, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.ANTIQUES_WITH_A_HISTORICAL_AND_OR_SOCIAL_SIGNIFICANCE, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.ELEMENTS_RELATED_TO_TECHNOLOGY_AND_THE_SCIENCES, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, INDUSTRIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.DOCUMENTARY_ELEMENTS, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.DISMEMBERED_ELEMENTS_FROM_ARTISTIC_OR_HISTORICAL_MONUMENTS_OR_ARCHAEOLOGICAL_SITES, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.MONUMENTS_BUILDINGS_AND_HERITAGE_SITES, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.ARCHAEOLOGICAL_HERITAGE_ELEMENTS, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.URBAN_ELEMENTS, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, URBAN_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.OTHERS, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, URBAN_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.ARTISTIC_AND_PERFORMING_MANIFESTATIONS_AND_EXPRESSIONS, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.LUDIC_EXPRESSION_AND_CELEBRATION, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.ORAL_TRADITION_AND_EXPRESSION, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.SOCIAL_USE_AND_PRACTICE, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.KNOWLEDGE_AND_PRACTICES_CONCERNING_NATURE_AND_THE_UNIVERSE, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.KNOWLEDGE_ON_TRADITIONAL_PRODUCTIVE_METHODS_AND_TECHNIQUES, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.CUSTOMARY_GOVERNANCE_SYSTEMS, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.AREA, List.of(FAMILY_TOURISM, NATURE_TOURISM, GEOLOGICAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.MONUMENT, List.of(FAMILY_TOURISM, NATURE_TOURISM, GEOLOGICAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.FLORA_AND_FAUNA, List.of(FAMILY_TOURISM, NATURE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.EVENT, List.of(FAMILY_TOURISM, NATURE_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.CULTURAL_LANDSCAPE, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, NATURE_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.DESIGNED_LANDSCAPE, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, NATURE_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
        SUBTYPE_TOURIST_TYPES_MAP.put(Subtype.TRADITIONAL_FORMS_OF_LAND_USE, List.of(FAMILY_TOURISM, CULTURAL_TOURISM, NATURE_TOURISM, HERITAGE_TOURISM, MEMORIAL_TOURISM));
    }

    public static List<TouristType> getTouristTypes(Subtype subtype) {
        return SUBTYPE_TOURIST_TYPES_MAP.get(subtype);
    }

    private static final EnumMap<Tag, List<TouristType>> TAG_TOURIST_TYPES_MAP = new EnumMap<>(Tag.class);

    static {
        TAG_TOURIST_TYPES_MAP.put(Tag.ELEMENTS_RELATED_TO_WORSHIP, List.of(RELIGIOUS_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.FUNERARY_ELEMENTS, List.of(RELIGIOUS_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.PHOTOGRAPHS_AND_NEGATIVES, List.of(FILM_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.SOUND_MATERIAL_AND_MUSICAL_RECORDINGS, List.of(FILM_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.AUDIO_VISUAL_PRODUCTIONS, List.of(FILM_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.DIGITAL_OBJECTS_AND_MULTIMEDIA_CREATIONS, List.of(FILM_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.PUBLIC_CIVIL_BUILDINGS, List.of(URBAN_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.RESIDENTIAL_BUILDINGS, List.of(URBAN_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.RELIGIOUS_CONSTRUCTIONS, List.of(RELIGIOUS_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.TRADITIONAL_RURAL_CONSTRUCTIONS_OF_ETHNOGRAPHIC_VALUE, List.of(RURAL_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.FUNERARY_CONSTRUCTIONS, List.of(RELIGIOUS_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.HISTORIC_SITES_OR_PLACES_AND_COMMEMORATIVE_ELEMENTS, List.of(MEMORIAL_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.MINING_AND_INDUSTRIAL_HERITAGE_ELEMENTS, List.of(INDUSTRIAL_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.CELEBRATION_SPORT_CHILDRENS_GAMES, List.of(EVENTS_AND_FESTIVALS_TOURISM, SPORTS_TOURISM)); //TODO review
        TAG_TOURIST_TYPES_MAP.put(Tag.RITUAL_AND_RELIGIOUS_PRACTICE, List.of(RELIGIOUS_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.DIETARY_HABIT, List.of(FOOD_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.COOKING_METHOD, List.of(FOOD_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.USES_AND_KNOWLEDGE_OF_INDIGENOUS_PEOPLE, List.of(ECOTOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.BIRDS, List.of(BIRDING_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.ASTRONOMIC, List.of(ASTRONOMY_TOURISM));
        TAG_TOURIST_TYPES_MAP.put(Tag.GEOLOGICAL, List.of(GEOLOGICAL_TOURISM));
    }

    public static List<TouristType> getTouristTypes(Tag tag) {
        return TAG_TOURIST_TYPES_MAP.get(tag);
    }
}
