package com.ocity.api.core.domain.heritage.schemaorg;

import com.ocity.api.core.domain.heritage.Subtype;
import com.ocity.api.core.domain.heritage.Tag;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

@Component
public class SchemaOrgTypeMapper {

    private static final Map<Subtype, SchemaOrgType> SUBTYPE_SCHEMAORG_TYPE_MAP = new HashMap<>();

    static {
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.ARCHAELOGICAL_ELEMENTS, SchemaOrgType.LAND_FORM);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.NATURAL_ELEMENT, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.OBJECTS_OF_ANTHROPOLOGICAL_OR_ETHNOLOGICAL_INTEREST, SchemaOrgType.LAND_FORM);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.WORKS_OF_ART, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.ANTIQUES_WITH_A_HISTORICAL_AND_OR_SOCIAL_SIGNIFICANCE, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.ELEMENTS_RELATED_TO_TECHNOLOGY_AND_THE_SCIENCES, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.DOCUMENTARY_ELEMENTS, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.DISMEMBERED_ELEMENTS_FROM_ARTISTIC_OR_HISTORICAL_MONUMENTS_OR_ARCHAEOLOGICAL_SITES, SchemaOrgType.LAND_FORM);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.MONUMENTS_BUILDINGS_AND_HERITAGE_SITES, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.ARCHAEOLOGICAL_HERITAGE_ELEMENTS, SchemaOrgType.LAND_FORM);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.URBAN_ELEMENTS, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.OTHERS, SchemaOrgType.BUSINESS_EVENT);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.ARTISTIC_AND_PERFORMING_MANIFESTATIONS_AND_EXPRESSIONS, SchemaOrgType.FESTIVAL);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.LUDIC_EXPRESSION_AND_CELEBRATION, SchemaOrgType.EVENT);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.ORAL_TRADITION_AND_EXPRESSION, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.SOCIAL_USE_AND_PRACTICE, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.KNOWLEDGE_AND_PRACTICES_CONCERNING_NATURE_AND_THE_UNIVERSE, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.KNOWLEDGE_ON_TRADITIONAL_PRODUCTIVE_METHODS_AND_TECHNIQUES, SchemaOrgType.EVENT);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.CUSTOMARY_GOVERNANCE_SYSTEMS, SchemaOrgType.EVENT);
//        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.AREA, SchemaOrgType.NATURE_PARK); //TODO review missing?
//        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.MONUMENT, SchemaOrgType.LAND_FORM); //TODO review missing?
//        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.FLORA_AND_FAUNA, SchemaOrgType.TOURIST_ATTRACTION); //TODO review missing?
//        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.EVENT, SchemaOrgType.TOURIST_ATTRACTION); //TODO review missing?
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.CULTURAL_LANDSCAPE, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.DESIGNED_LANDSCAPE, SchemaOrgType.TOURIST_ATTRACTION);
        SUBTYPE_SCHEMAORG_TYPE_MAP.put(Subtype.TRADITIONAL_FORMS_OF_LAND_USE, SchemaOrgType.TOURIST_ATTRACTION);
    }

    public static SchemaOrgType getSchemaOrgType(Subtype subtype) { //TODO add to domain builder
        return SUBTYPE_SCHEMAORG_TYPE_MAP.get(subtype);
    }

    private static final Map<Tag, SchemaOrgType> TAG_SCHEMAORG_TYPE_MAP = new HashMap<>();

    static {
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ARTEFACTS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.OBJECTS_AND_STATUES_MADE_OF_STONE_WOOD_BONE_METAL_CERAMICS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TEXTILE_ELEMENTS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DECORATED_PLATELETS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MUMMIES, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SHIPWRECKS, SchemaOrgType.LAND_FORM);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.PALEONTOLOGICAL_REMAINS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.METEORITICS, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.RITUAL_OBJECTS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TOOLS_AND_DOMESTIC_IMPLEMENTS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.CRAFTWORK, SchemaOrgType.LAND_FORM);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.PAINTINGS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DRAWINGS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ENGRAVINGS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SCULPTURES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.GRAPHICAL_SERIE_WORKS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DECORATIVE_ARTS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ART_INSTALLATIONS, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ELEMENTS_RELATED_TO_WORSHIP, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FUNERARY_ELEMENTS, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.EVERYDAY_LIFE_ELEMENTS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MILITARY_OBJECTS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MUSICAL_INSTRUMENTS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.NUMISMATIC_AND_PHILATELIC_ELEMENTS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.COMMEMORATIVE_WORKS, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.UTIENSILS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.INSTRUMENTS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.WORK_TOOLS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TECHNOLOGICAL_EQUIPMENT, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MACHINES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.VEHICLES, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.BOOKS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SERIAL_PUBLICATIONS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ADMINISTRATIVE_ARCHIVES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MUSICAL_SCORES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MAPS_AND_OTHER_CARTOGRAPHIC_MATERIALS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.PHOTOGRAPHS_AND_NEGATIVES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SOUND_MATERIAL_AND_MUSICAL_RECORDINGS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.AUDIO_VISUAL_PRODUCTIONS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ELECTRONIC_RESOURCES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DIGITAL_OBJECTS_AND_MULTIMEDIA_CREATIONS, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.REMAINS_OF_STRUCTURES, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ORNAMENTAL_ELEMENTS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FUNCTIONAL_ELEMENTS, SchemaOrgType.LAND_FORM);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.PUBLIC_CIVIL_BUILDINGS, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.RESIDENTIAL_BUILDINGS, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.RELIGIOUS_CONSTRUCTIONS, SchemaOrgType.PLACE_OF_WORSHIP);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DEFENSE_CONSTRUCTIONS, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_RURAL_CONSTRUCTIONS_OF_ETHNOGRAPHIC_VALUE, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FUNERARY_CONSTRUCTIONS, SchemaOrgType.CEMETERY);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.HISTORIC_SITES_OR_PLACES_AND_COMMEMORATIVE_ELEMENTS, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MINING_AND_INDUSTRIAL_HERITAGE_ELEMENTS, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ARCHAEOLOGICAL_SITE, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ROCKY_OR_PARIETAL_PAINTINGS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ARCHAEOLOGICAL_AREA, SchemaOrgType.LAND_FORM);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.URBAN_LAYOUT, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.URBAN_LANDMARK, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DISTRICTS, SchemaOrgType.CITY);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TECHNOLOGICAL_CENTRES, SchemaOrgType.CIVIC_STRUCTURE);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ENGINEERING_WORKS, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MODERN_ARCHITECTURE, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.LITERATURE, SchemaOrgType.FESTIVAL);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MUSIC, SchemaOrgType.MUSIC_EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DANCE, SchemaOrgType.MUSIC_EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.THEATRE, SchemaOrgType.MOVIE_THEATER);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.CELEBRATION_SPORT_CHILDRENS_GAMES, SchemaOrgType.EVENT); //TODO review

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.LANGUAGE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DIALECT, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TOPONYM, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ORAL_EXPRESSION, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.LOCAL_MEMORY_LINKED_TO_HISTORICAL_EVENT_AND_PLACE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MUSICAL_PIECE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.POPULAR_ANONYM_SONG, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.BELIEF, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.RITUAL_AND_RELIGIOUS_PRACTICE, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_AND_COMMUNAL_PRACTICE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.PEOPLES_BEHAVIOURAL_PATTERN, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.POPULAR_TRADITION, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DIETARY_HABIT, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.COOKING_METHOD, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_SCIENTIFIC_AND_HUMANISTIC_KNOWLEDGE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_ECOLOGICAL_KNOWLEDGE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.USES_AND_KNOWLEDGE_OF_INDIGENOUS_PEOPLE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_HEALTH_AND_MEDICINE_PRACTICES_AND_KNOWLEDGE, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_CRAFTSMANSHIP, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SETTLEMENT_PATTERN_AND_TRADITIONAL_CONSTRUCTION_TECHNIQUE, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_OCCUPATION, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_PRODUCTIVE_TECHNIQUE_AND_KNOWLEDGE, SchemaOrgType.EVENT);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_INSTITUTION, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_RULES_OR_NORMS, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.CUSTOMARY_LEGAL_SYSTEM, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SOCIAL_VALUE_SYSTEM, SchemaOrgType.EVENT);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_SOCIAL_ORGANIZATION, SchemaOrgType.EVENT);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.NATURAL_PARK, SchemaOrgType.PLACE);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.GEOPARK, SchemaOrgType.PLACE);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.NATURAL_RESERVE, SchemaOrgType.PLACE);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.WETLAND, SchemaOrgType.BODY_OF_WATER);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MARINE_AREA, SchemaOrgType.BODY_OF_WATER);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.BIOSPHERE, SchemaOrgType.PLACE);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.AEOLIAN, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.EROSION_LANDFORMS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FLUVIAL_LANDFORMS, SchemaOrgType.BODY_OF_WATER);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.IMPACT_LANDFORMS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.KARST_LANDFORMS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.LACUSTRINE_LANDFORMS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MOUNTAIN_AND_GLACIAL_LANDFORMS, SchemaOrgType.MOUNTAIN);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SLOPE_LANDFORMS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TECTONIC_LANDFORMS, SchemaOrgType.VOLCANO);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.VOLCANIC_LANDFORMS, SchemaOrgType.VOLCANO);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.WEATHERING_LANDFORMS, SchemaOrgType.LAND_FORM);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.CLOSED_FORESTS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.WOODLANDS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FOURRES_THICKETS_OR_SHRUBLANDS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DWARF_SCRUB_AND_RELATED_COMMUNITIES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TERRESTRIAL_HERBACEOUS_COMMUNITIES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.DESERTS_AND_OTHER_SCARCELY_VEGETATED_AREAS, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.AQUATIC_PLANT_FORMATIONS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TREE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FLOWER, SchemaOrgType.TOURIST_ATTRACTION); //TODO review
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.BIRDS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MAMMALS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.AMPHIBIANS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.REPTILES, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FISH, SchemaOrgType.TOURIST_ATTRACTION); //TODO review
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MOLLUSCS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.INSECTS, SchemaOrgType.TOURIST_ATTRACTION); //TODO review

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ASTRONOMIC, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ATMOSPHERIC, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.GEOLOGICAL, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FLOWER, SchemaOrgType.TOURIST_ATTRACTION); //TODO review
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FISH, SchemaOrgType.TOURIST_ATTRACTION); //TODO review
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FISH_OVIPOSITION, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.INSECTS, SchemaOrgType.TOURIST_ATTRACTION); //TODO review
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.INSECT_METAMORPHOSIS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ZEAL_AND_REPRODUCTION_OF_ANIMALS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.MIGRATION, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SACRED_NATURAL_LANDSCAPE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.LANDSCAPE_OF_SPIRITUAL_SIGNIFICANCE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.LANDSCAPE_OF_AESTHETIC_SIGNIFICANCE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.AGRICULTURAL_LANDSCAPE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ARCHEOLOGICAL_SITE, SchemaOrgType.LAND_FORM);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.HISTORIC_SITE, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.INDUSTRIAL_SITE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.PASTORAL_LANDSCAPE, SchemaOrgType.TOURIST_ATTRACTION);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.GARDEN_AND_PARKLAND_LANDSCAPE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.BOTANICAL_GARDEN, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.CEMETERIES, SchemaOrgType.CEMETERY);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.HISTORIC_TOWN_OR_VILLAGE, SchemaOrgType.LANDMARKS_OR_HISTORICAL_BUILDINGS);

        TAG_SCHEMAORG_TYPE_MAP.put(Tag.CULTIVATION_PRACTICE, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.FARMING_SYSTEM, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.PLANTATIONS_AND_CROPS, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.ANIMAL_HUSBANDRY, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.TRADITIONAL_KNOW_HOW, SchemaOrgType.TOURIST_ATTRACTION);
        TAG_SCHEMAORG_TYPE_MAP.put(Tag.SUSTAINABLE_LAND_USE, SchemaOrgType.TOURIST_ATTRACTION);
    }

    public static SchemaOrgType getSchemaOrgType(Tag tag) {
        return TAG_SCHEMAORG_TYPE_MAP.get(tag);
    }
}
