package com.ocity.api.core.domain.heritage.une;

import com.ocity.api.core.domain.heritage.Subtype;
import com.ocity.api.core.domain.heritage.Tag;

import java.util.HashMap;
import java.util.Map;

public class UneTypeMapper {

    private static final Map<Subtype, UNEType> SUBTYPE_UNE_TYPE_MAP = new HashMap<>();

    static {
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.ARCHAELOGICAL_ELEMENTS, UNEType.CAVE);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.NATURAL_ELEMENT, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.OBJECTS_OF_ANTHROPOLOGICAL_OR_ETHNOLOGICAL_INTEREST, UNEType.CAVE);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.WORKS_OF_ART, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.ANTIQUES_WITH_A_HISTORICAL_AND_OR_SOCIAL_SIGNIFICANCE, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.ELEMENTS_RELATED_TO_TECHNOLOGY_AND_THE_SCIENCES, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.DOCUMENTARY_ELEMENTS, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.DISMEMBERED_ELEMENTS_FROM_ARTISTIC_OR_HISTORICAL_MONUMENTS_OR_ARCHAEOLOGICAL_SITES, UNEType.CAVE);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.MONUMENTS_BUILDINGS_AND_HERITAGE_SITES, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.ARCHAEOLOGICAL_HERITAGE_ELEMENTS, UNEType.CAVE);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.URBAN_ELEMENTS, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.OTHERS, UNEType.BUSINESS_EVENT);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.ARTISTIC_AND_PERFORMING_MANIFESTATIONS_AND_EXPRESSIONS, UNEType.FESTIVAL);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.LUDIC_EXPRESSION_AND_CELEBRATION, UNEType.EVENT);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.ORAL_TRADITION_AND_EXPRESSION, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.SOCIAL_USE_AND_PRACTICE, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.KNOWLEDGE_AND_PRACTICES_CONCERNING_NATURE_AND_THE_UNIVERSE, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.KNOWLEDGE_ON_TRADITIONAL_PRODUCTIVE_METHODS_AND_TECHNIQUES, UNEType.EVENT);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.CUSTOMARY_GOVERNANCE_SYSTEMS, UNEType.EVENT);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.AREA, UNEType.NATURE_PARK);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.MONUMENT, UNEType.LAND_FORM);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.FLORA_AND_FAUNA, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.EVENT, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.CULTURAL_LANDSCAPE, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.DESIGNED_LANDSCAPE, UNEType.TOURIST_ATTRACTION);
        SUBTYPE_UNE_TYPE_MAP.put(Subtype.TRADITIONAL_FORMS_OF_LAND_USE, UNEType.TOURIST_ATTRACTION);
    }

    public static UNEType getUneType(Subtype subtype) { //TODO add to domain builder
        return SUBTYPE_UNE_TYPE_MAP.get(subtype);
    }

    private static final Map<Tag, UNEType> TAG_UNE_TYPE_MAP = new HashMap<>();

    static {
        TAG_UNE_TYPE_MAP.put(Tag.ARTEFACTS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.OBJECTS_AND_STATUES_MADE_OF_STONE_WOOD_BONE_METAL_CERAMICS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.TEXTILE_ELEMENTS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.DECORATED_PLATELETS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.MUMMIES, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.SHIPWRECKS, UNEType.CAVE);

        TAG_UNE_TYPE_MAP.put(Tag.PALEONTOLOGICAL_REMAINS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.METEORITICS, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.RITUAL_OBJECTS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.TOOLS_AND_DOMESTIC_IMPLEMENTS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.CRAFTWORK, UNEType.CAVE);

        TAG_UNE_TYPE_MAP.put(Tag.PAINTINGS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.DRAWINGS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ENGRAVINGS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.SCULPTURES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.GRAPHICAL_SERIE_WORKS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.DECORATIVE_ARTS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ART_INSTALLATIONS, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.ELEMENTS_RELATED_TO_WORSHIP, UNEType.RELIGION_EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.FUNERARY_ELEMENTS, UNEType.RELIGION_EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.EVERYDAY_LIFE_ELEMENTS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MILITARY_OBJECTS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MUSICAL_INSTRUMENTS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.NUMISMATIC_AND_PHILATELIC_ELEMENTS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.COMMEMORATIVE_WORKS, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.UTIENSILS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.INSTRUMENTS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.WORK_TOOLS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.TECHNOLOGICAL_EQUIPMENT, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MACHINES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.VEHICLES, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.BOOKS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.SERIAL_PUBLICATIONS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ADMINISTRATIVE_ARCHIVES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MUSICAL_SCORES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MAPS_AND_OTHER_CARTOGRAPHIC_MATERIALS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.PHOTOGRAPHS_AND_NEGATIVES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.SOUND_MATERIAL_AND_MUSICAL_RECORDINGS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.AUDIO_VISUAL_PRODUCTIONS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ELECTRONIC_RESOURCES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.DIGITAL_OBJECTS_AND_MULTIMEDIA_CREATIONS, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.REMAINS_OF_STRUCTURES, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.ORNAMENTAL_ELEMENTS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.FUNCTIONAL_ELEMENTS, UNEType.CAVE);

        TAG_UNE_TYPE_MAP.put(Tag.PUBLIC_CIVIL_BUILDINGS, UNEType.CIVIL_BUILDING);
        TAG_UNE_TYPE_MAP.put(Tag.RESIDENTIAL_BUILDINGS, UNEType.CIVIL_BUILDING);
        TAG_UNE_TYPE_MAP.put(Tag.RELIGIOUS_CONSTRUCTIONS, UNEType.PLACE_OF_WORSHIP);
        TAG_UNE_TYPE_MAP.put(Tag.DEFENSE_CONSTRUCTIONS, UNEType.MILITARY_BUILDINGS);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_RURAL_CONSTRUCTIONS_OF_ETHNOGRAPHIC_VALUE, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_UNE_TYPE_MAP.put(Tag.FUNERARY_CONSTRUCTIONS, UNEType.CEMETERY);
        TAG_UNE_TYPE_MAP.put(Tag.HISTORIC_SITES_OR_PLACES_AND_COMMEMORATIVE_ELEMENTS, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_UNE_TYPE_MAP.put(Tag.MINING_AND_INDUSTRIAL_HERITAGE_ELEMENTS, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);

        TAG_UNE_TYPE_MAP.put(Tag.ARCHAEOLOGICAL_SITE, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.ROCKY_OR_PARIETAL_PAINTINGS, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.ARCHAEOLOGICAL_AREA, UNEType.CAVE);

        TAG_UNE_TYPE_MAP.put(Tag.URBAN_LAYOUT, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_UNE_TYPE_MAP.put(Tag.URBAN_LANDMARK, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_UNE_TYPE_MAP.put(Tag.DISTRICTS, UNEType.CITY);

        TAG_UNE_TYPE_MAP.put(Tag.TECHNOLOGICAL_CENTRES, UNEType.CULTURE_CENTER);
        TAG_UNE_TYPE_MAP.put(Tag.ENGINEERING_WORKS, UNEType.CIVIL_BUILDING);
        TAG_UNE_TYPE_MAP.put(Tag.MODERN_ARCHITECTURE, UNEType.CIVIL_BUILDING);

        TAG_UNE_TYPE_MAP.put(Tag.LITERATURE, UNEType.TRADITIONAL_FESTIVAL);
        TAG_UNE_TYPE_MAP.put(Tag.MUSIC, UNEType.MUSIC_EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.DANCE, UNEType.MUSIC_EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.THEATRE, UNEType.MOVIE_THEATER);

        TAG_UNE_TYPE_MAP.put(Tag.CELEBRATION_SPORT_CHILDRENS_GAMES, UNEType.EVENT); //TODO review

        TAG_UNE_TYPE_MAP.put(Tag.LANGUAGE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.DIALECT, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.TOPONYM, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ORAL_EXPRESSION, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.LOCAL_MEMORY_LINKED_TO_HISTORICAL_EVENT_AND_PLACE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MUSICAL_PIECE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.POPULAR_ANONYM_SONG, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.BELIEF, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.RITUAL_AND_RELIGIOUS_PRACTICE, UNEType.RELIGION_EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_AND_COMMUNAL_PRACTICE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.PEOPLES_BEHAVIOURAL_PATTERN, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.POPULAR_TRADITION, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.DIETARY_HABIT, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.COOKING_METHOD, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_SCIENTIFIC_AND_HUMANISTIC_KNOWLEDGE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_ECOLOGICAL_KNOWLEDGE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.USES_AND_KNOWLEDGE_OF_INDIGENOUS_PEOPLE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_HEALTH_AND_MEDICINE_PRACTICES_AND_KNOWLEDGE, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_CRAFTSMANSHIP, UNEType.EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.SETTLEMENT_PATTERN_AND_TRADITIONAL_CONSTRUCTION_TECHNIQUE, UNEType.EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_OCCUPATION, UNEType.EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_PRODUCTIVE_TECHNIQUE_AND_KNOWLEDGE, UNEType.EVENT);

        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_INSTITUTION, UNEType.EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_RULES_OR_NORMS, UNEType.EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.CUSTOMARY_LEGAL_SYSTEM, UNEType.EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.SOCIAL_VALUE_SYSTEM, UNEType.EVENT);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_SOCIAL_ORGANIZATION, UNEType.EVENT);

        TAG_UNE_TYPE_MAP.put(Tag.NATURAL_PARK, UNEType.NATURE_PARK);
        TAG_UNE_TYPE_MAP.put(Tag.GEOPARK, UNEType.NATURE_PARK);
        TAG_UNE_TYPE_MAP.put(Tag.NATURAL_RESERVE, UNEType.NATURE_PARK);
        TAG_UNE_TYPE_MAP.put(Tag.WETLAND, UNEType.BODY_OF_WATER);
        TAG_UNE_TYPE_MAP.put(Tag.MARINE_AREA, UNEType.BODY_OF_WATER);
        TAG_UNE_TYPE_MAP.put(Tag.BIOSPHERE, UNEType.NATURE_PARK);

        TAG_UNE_TYPE_MAP.put(Tag.AEOLIAN, UNEType.LAND_FORM);
        TAG_UNE_TYPE_MAP.put(Tag.EROSION_LANDFORMS, UNEType.LAND_FORM);
        TAG_UNE_TYPE_MAP.put(Tag.FLUVIAL_LANDFORMS, UNEType.BODY_OF_WATER);
        TAG_UNE_TYPE_MAP.put(Tag.IMPACT_LANDFORMS, UNEType.LAND_FORM);
        TAG_UNE_TYPE_MAP.put(Tag.KARST_LANDFORMS, UNEType.LAND_FORM);
        TAG_UNE_TYPE_MAP.put(Tag.LACUSTRINE_LANDFORMS, UNEType.LAND_FORM);
        TAG_UNE_TYPE_MAP.put(Tag.MOUNTAIN_AND_GLACIAL_LANDFORMS, UNEType.MOUNTAIN);
        TAG_UNE_TYPE_MAP.put(Tag.SLOPE_LANDFORMS, UNEType.LAND_FORM);
        TAG_UNE_TYPE_MAP.put(Tag.TECTONIC_LANDFORMS, UNEType.VOLCANO);
        TAG_UNE_TYPE_MAP.put(Tag.VOLCANIC_LANDFORMS, UNEType.VOLCANO);
        TAG_UNE_TYPE_MAP.put(Tag.WEATHERING_LANDFORMS, UNEType.LAND_FORM);

        TAG_UNE_TYPE_MAP.put(Tag.CLOSED_FORESTS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.WOODLANDS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.FOURRES_THICKETS_OR_SHRUBLANDS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.DWARF_SCRUB_AND_RELATED_COMMUNITIES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.TERRESTRIAL_HERBACEOUS_COMMUNITIES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.DESERTS_AND_OTHER_SCARCELY_VEGETATED_AREAS, UNEType.DESERT);
        TAG_UNE_TYPE_MAP.put(Tag.AQUATIC_PLANT_FORMATIONS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.TREE, UNEType.TREE);
        TAG_UNE_TYPE_MAP.put(Tag.FLOWER, UNEType.TOURIST_ATTRACTION); //TODO review
        TAG_UNE_TYPE_MAP.put(Tag.BIRDS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MAMMALS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.AMPHIBIANS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.REPTILES, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.FISH, UNEType.TOURIST_ATTRACTION); //TODO review
        TAG_UNE_TYPE_MAP.put(Tag.MOLLUSCS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.INSECTS, UNEType.TOURIST_ATTRACTION); //TODO review

        TAG_UNE_TYPE_MAP.put(Tag.ASTRONOMIC, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ATMOSPHERIC, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.GEOLOGICAL, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.FLOWER, UNEType.TOURIST_ATTRACTION); //TODO review
        TAG_UNE_TYPE_MAP.put(Tag.FISH, UNEType.TOURIST_ATTRACTION); //TODO review
        TAG_UNE_TYPE_MAP.put(Tag.FISH_OVIPOSITION, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.INSECTS, UNEType.TOURIST_ATTRACTION); //TODO review
        TAG_UNE_TYPE_MAP.put(Tag.INSECT_METAMORPHOSIS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ZEAL_AND_REPRODUCTION_OF_ANIMALS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.MIGRATION, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.SACRED_NATURAL_LANDSCAPE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.LANDSCAPE_OF_SPIRITUAL_SIGNIFICANCE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.LANDSCAPE_OF_AESTHETIC_SIGNIFICANCE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.AGRICULTURAL_LANDSCAPE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ARCHEOLOGICAL_SITE, UNEType.CAVE);
        TAG_UNE_TYPE_MAP.put(Tag.HISTORIC_SITE, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);
        TAG_UNE_TYPE_MAP.put(Tag.INDUSTRIAL_SITE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.PASTORAL_LANDSCAPE, UNEType.TOURIST_ATTRACTION);

        TAG_UNE_TYPE_MAP.put(Tag.GARDEN_AND_PARKLAND_LANDSCAPE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.BOTANICAL_GARDEN, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.CEMETERIES, UNEType.CEMETERY);
        TAG_UNE_TYPE_MAP.put(Tag.HISTORIC_TOWN_OR_VILLAGE, UNEType.LANDMARKS_OR_HISTORICAL_BUILDINGS);

        TAG_UNE_TYPE_MAP.put(Tag.CULTIVATION_PRACTICE, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.FARMING_SYSTEM, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.PLANTATIONS_AND_CROPS, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.ANIMAL_HUSBANDRY, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.TRADITIONAL_KNOW_HOW, UNEType.TOURIST_ATTRACTION);
        TAG_UNE_TYPE_MAP.put(Tag.SUSTAINABLE_LAND_USE, UNEType.TOURIST_ATTRACTION);
    }

    public static UNEType getUneType(Tag tag) {
        return TAG_UNE_TYPE_MAP.get(tag);
    }
}
