package com.ocity.api.core.infrastructure.heritage;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ocity.api.core.application.heritage.FindDataByCityId;
import com.ocity.api.core.application.heritage.FindDataByCountryId;
import com.ocity.api.core.application.heritage.FindDataByRegionId;
import com.ocity.api.core.application.heritage.FindDataByStateId;
import com.ocity.api.core.application.heritage.FindDataBySubregionId;
import com.ocity.api.core.application.heritage.dto.HeritageItemDTO;
import com.ocity.api.core.application.heritage.dto.in.CategoriesDTO;
import com.ocity.api.core.application.heritage.dto.in.HeritageFormat;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
public class HeritageController {

    private final FindDataByRegionId findDataByRegionId;
    private final FindDataBySubregionId findDataBySubregionId;
    private final FindDataByCountryId findDataByCountryId;
    private final FindDataByStateId findDataByStateId;
    private final FindDataByCityId findDataByCityId;
    private final ObjectMapper objectMapper;

    @Autowired
    public HeritageController(FindDataByRegionId findDataByRegionId, FindDataBySubregionId findDataBySubregionId, FindDataByCountryId findDataByCountryId, FindDataByStateId findDataByStateId, FindDataByCityId findDataByCityId, ObjectMapper objectMapper) {
        this.findDataByRegionId = findDataByRegionId;
        this.findDataBySubregionId = findDataBySubregionId;
        this.findDataByCountryId = findDataByCountryId;
        this.findDataByStateId = findDataByStateId;
        this.findDataByCityId = findDataByCityId;
        this.objectMapper = objectMapper;
    }

    @GetMapping("/regions/{regionId}/data")
    public ResponseEntity<List<HeritageItemDTO>> getDataByRegionId(
            @PathVariable Integer regionId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        return new ResponseEntity<>(findDataByRegionId.execute(regionId, categoriesDTO, dataFormat), HttpStatus.OK);
    }

    @GetMapping("/subregions/{subregionId}/data")
    public ResponseEntity<List<HeritageItemDTO>> getDataBySubregionId(
            @PathVariable Integer subregionId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        return new ResponseEntity<>(findDataBySubregionId.execute(subregionId, categoriesDTO, dataFormat), HttpStatus.OK);
    }

    @GetMapping("/countries/{countryId}/data")
    public ResponseEntity<List<HeritageItemDTO>> getDataByCountryId(
            @PathVariable Integer countryId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        return new ResponseEntity<>(findDataByCountryId.execute(countryId, categoriesDTO, dataFormat), HttpStatus.OK);
    }

    @GetMapping("/states/{stateId}/data")
    public ResponseEntity<List<HeritageItemDTO>> getDataByStateId(
            @PathVariable Integer stateId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        return new ResponseEntity<>(findDataByStateId.execute(stateId, categoriesDTO, dataFormat), HttpStatus.OK);
    }

    @GetMapping("/cities/{cityId}/data")
    public ResponseEntity<List<HeritageItemDTO>> getDataByCityId(
            @PathVariable Integer cityId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        return new ResponseEntity<>(findDataByCityId.execute(cityId, categoriesDTO, dataFormat), HttpStatus.OK);
    }

    @GetMapping("/regions/{regionId}/download")
    public ResponseEntity<byte[]> downloadDataByRegionId(
            @PathVariable Integer regionId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) throws JsonProcessingException {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        List<HeritageItemDTO> heritageData = findDataByRegionId.execute(regionId, categoriesDTO, dataFormat);

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
        headers.setContentDispositionFormData("attachment", String.format("regionId-%d.json", regionId));

        return new ResponseEntity<>(objectMapper.writeValueAsBytes(heritageData), headers, HttpStatus.OK);
    }

    @GetMapping("/subregions/{subregionId}/download")
    public ResponseEntity<byte[]> downloadDataBySubregionId(
            @PathVariable Integer subregionId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) throws JsonProcessingException {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        List<HeritageItemDTO> heritageData = findDataBySubregionId.execute(subregionId, categoriesDTO, dataFormat);

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
        headers.setContentDispositionFormData("attachment", String.format("subregionId-%d.json", subregionId));

        return new ResponseEntity<>(objectMapper.writeValueAsBytes(heritageData), headers, HttpStatus.OK);
    }

    @GetMapping("/countries/{countryId}/download")
    public ResponseEntity<byte[]> downloadDataByCountryId(
            @PathVariable Integer countryId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) throws JsonProcessingException {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        List<HeritageItemDTO> heritageData = findDataByCountryId.execute(countryId, categoriesDTO, dataFormat);

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
        headers.setContentDispositionFormData("attachment", String.format("countryId-%d.json", countryId));

        return new ResponseEntity<>(objectMapper.writeValueAsBytes(heritageData), headers, HttpStatus.OK);
    }

    @GetMapping("/states/{stateId}/download")
    public ResponseEntity<byte[]> downloadDataByStateId(
            @PathVariable Integer stateId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) throws JsonProcessingException {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        List<HeritageItemDTO> heritageData = findDataByStateId.execute(stateId, categoriesDTO, dataFormat);

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
        headers.setContentDispositionFormData("attachment", String.format("stateId-%d.json", stateId));

        return new ResponseEntity<>(objectMapper.writeValueAsBytes(heritageData), headers, HttpStatus.OK);
    }

    @GetMapping("/cities/{cityId}/download")
    public ResponseEntity<byte[]> downloadDataByCityId(
            @PathVariable Integer cityId,
            @RequestParam(required = false, name = "cultural-category") Boolean culturalCategory,
            @RequestParam(required = false, name = "natural-category") Boolean naturalCategory,
            @RequestParam(required = false, name = "mixed-category") Boolean mixedCategory,
            @RequestParam(required = true, name = "data-format") Integer dataFormatId
    ) throws JsonProcessingException {
        CategoriesDTO categoriesDTO = new CategoriesDTO(culturalCategory, naturalCategory, mixedCategory);
        HeritageFormat dataFormat = HeritageFormat.getById(dataFormatId);
        List<HeritageItemDTO> heritageData = findDataByCityId.execute(cityId, categoriesDTO, dataFormat);

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
        headers.setContentDispositionFormData("attachment", String.format("cityId-%d.json", cityId));

        return new ResponseEntity<>(objectMapper.writeValueAsBytes(heritageData), headers, HttpStatus.OK);
    }

}
