package com.ocity.api.core.infrastructure.heritage.entity;

import jakarta.persistence.Entity;
import jakarta.persistence.Id;
import jakarta.persistence.NamedQueries;
import jakarta.persistence.NamedQuery;

@Entity
@NamedQueries({
        @NamedQuery(
                name = HeritageItemEntity.FIND_BY_REGION_ID_AND_CATEGORIES,
                query = " SELECT new HeritageItemEntity( " +
                        " hl.id, " +
                        " hl.name, " +
                        " ci.countryCode, " +
                        " ci.name, " +
                        " hl.latitude, " +
                        " hl.longitude, " +
                        " hl.shortLocalHeritageDescription, " +
                        " hl.shortHeritageDescription, " +
                        " hl.image, " +
                        " hl.tags, " +
                        " hl.subtype, " +
                        " hl.isMuseum ) " +
                        " FROM HeritageListEntity hl " +
                        " JOIN CityEntity ci ON ci.id = hl.cityId " +
                        " JOIN FieldTypeEntity t ON t.id = hl.heritageFieldId " +
                        " JOIN FieldEntity cat ON cat.id = t.fieldId " +
                        " WHERE hl.countryId IN :countryIds " +
                        " AND cat.id IN :categories "
        ),
        @NamedQuery(
                name = HeritageItemEntity.FIND_BY_SUBREGION_ID_AND_CATEGORIES,
                query = " SELECT new HeritageItemEntity( " +
                        " hl.id, " +
                        " hl.name, " +
                        " ci.countryCode, " +
                        " ci.name, " +
                        " hl.latitude, " +
                        " hl.longitude, " +
                        " hl.shortLocalHeritageDescription, " +
                        " hl.shortHeritageDescription, " +
                        " hl.image, " +
                        " hl.tags, " +
                        " hl.subtype, " +
                        " hl.isMuseum ) " +
                        " FROM HeritageListEntity hl " +
                        " JOIN CityEntity ci ON ci.id = hl.cityId " +
                        " JOIN FieldTypeEntity t ON t.id = hl.heritageFieldId " +
                        " JOIN FieldEntity cat ON cat.id = t.fieldId " +
                        " WHERE hl.countryId IN :countryIds " +
                        " AND cat.id IN :categories "
        ),
        @NamedQuery(
                name = HeritageItemEntity.FIND_BY_COUNTRY_ID_AND_CATEGORIES,
                query = " SELECT new HeritageItemEntity( " +
                        " hl.id, " +
                        " hl.name, " +
                        " ci.countryCode, " +
                        " ci.name, " +
                        " hl.latitude, " +
                        " hl.longitude, " +
                        " hl.shortLocalHeritageDescription, " +
                        " hl.shortHeritageDescription, " +
                        " hl.image, " +
                        " hl.tags, " +
                        " hl.subtype, " +
                        " hl.isMuseum ) " +
                        " FROM HeritageListEntity hl " +
                        " JOIN CityEntity ci ON ci.id = hl.cityId " +
                        " JOIN FieldTypeEntity t ON t.id = hl.heritageFieldId " +
                        " JOIN FieldEntity cat ON cat.id = t.fieldId " +
                        " WHERE hl.countryId = :countryId " +
                        " AND cat.id IN :categories "
        ),
        @NamedQuery(
                name = HeritageItemEntity.FIND_BY_STATE_ID_AND_CATEGORIES,
                query = " SELECT new HeritageItemEntity( " +
                        " hl.id, " +
                        " hl.name, " +
                        " ci.countryCode, " +
                        " ci.name, " +
                        " hl.latitude, " +
                        " hl.longitude, " +
                        " hl.shortLocalHeritageDescription, " +
                        " hl.shortHeritageDescription, " +
                        " hl.image, " +
                        " hl.tags, " +
                        " hl.subtype, " +
                        " hl.isMuseum ) " +
                        " FROM HeritageListEntity hl " +
                        " JOIN CityEntity ci ON ci.id = hl.cityId " +
                        " JOIN StateEntity st ON st.id = hl.stateId " +
                        " JOIN FieldTypeEntity t ON t.id = hl.heritageFieldId " +
                        " JOIN FieldEntity cat ON cat.id = t.fieldId " +
                        " WHERE st.id = :stateId " +
                        " AND cat.id IN :categories "
        ),
        @NamedQuery(
                name = HeritageItemEntity.FIND_BY_CITY_ID_AND_CATEGORIES,
                query = " SELECT new HeritageItemEntity( " +
                        " hl.id, " +
                        " hl.name, " +
                        " ci.countryCode, " +
                        " ci.name, " +
                        " hl.latitude, " +
                        " hl.longitude, " +
                        " hl.shortLocalHeritageDescription, " +
                        " hl.shortHeritageDescription, " +
                        " hl.image, " +
                        " hl.tags, " +
                        " hl.subtype," +
                        " hl.isMuseum ) " +
                        " FROM HeritageListEntity hl " +
                        " JOIN CityEntity ci ON ci.id = hl.cityId " +
                        " JOIN FieldTypeEntity t ON t.id = hl.heritageFieldId " +
                        " JOIN FieldEntity cat ON cat.id = t.fieldId " +
                        " WHERE ci.id = :cityId " +
                        " AND cat.id IN :categories "
        )
})
public class HeritageItemEntity {

    public static final String FIND_BY_REGION_ID_AND_CATEGORIES = "HeritageItemEntity.FIND_BY_REGION_ID_AND_CATEGORIES";
    public static final String FIND_BY_SUBREGION_ID_AND_CATEGORIES = "HeritageItemEntity.FIND_BY_SUBREGION_ID_AND_CATEGORIES";
    public static final String FIND_BY_COUNTRY_ID_AND_CATEGORIES = "HeritageItemEntity.FIND_BY_COUNTRY_ID_AND_CATEGORIES";
    public static final String FIND_BY_STATE_ID_AND_CATEGORIES = "HeritageItemEntity.FIND_BY_STATE_ID_AND_CATEGORIES";
    public static final String FIND_BY_CITY_ID_AND_CATEGORIES = "HeritageItemEntity.FIND_BY_CITY_ID_AND_CATEGORIES";

    @Id
    private Integer id;
    private String name;
    private String countryCode;
    private String cityName;
    private Double latitude;
    private Double longitude;
    private String shortLocalHeritageDescription;
    private String shortHeritageDescription;
    private String image;
    private String tags;
    private String subtype;
    private Boolean isMuseum;

    public HeritageItemEntity() {
    }

    public HeritageItemEntity(Integer id,
                              String name,
                              String countryCode,
                              String cityName,
                              Double latitude,
                              Double longitude,
                              String shortLocalHeritageDescription,
                              String shortHeritageDescription,
                              String image,
                              String tags,
                              String subtype,
                              Boolean isMuseum) {
        this.id = id;
        this.name = name;
        this.countryCode = countryCode;
        this.cityName = cityName;
        this.latitude = latitude;
        this.longitude = longitude;
        this.shortLocalHeritageDescription = shortLocalHeritageDescription;
        this.shortHeritageDescription = shortHeritageDescription;
        this.image = image;
        this.tags = tags;
        this.subtype = subtype;
        this.isMuseum = isMuseum;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }

    public String getShortLocalHeritageDescription() {
        return shortLocalHeritageDescription;
    }

    public void setShortLocalHeritageDescription(String shortLocalHeritageDescription) {
        this.shortLocalHeritageDescription = shortLocalHeritageDescription;
    }

    public String getShortHeritageDescription() {
        return shortHeritageDescription;
    }

    public void setShortHeritageDescription(String shortHeritageDescription) {
        this.shortHeritageDescription = shortHeritageDescription;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getSubtype() {
        return subtype;
    }

    public void setSubtype(String subtype) {
        this.subtype = subtype;
    }

    public Boolean getIsMuseum() {
        return isMuseum;
    }

    public void setIsMuseum(Boolean museum) {
        isMuseum = museum;
    }
}
