package com.ocity.api.core.infrastructure.locations;

import com.ocity.api.core.application.locations.FindAllCountries;
import com.ocity.api.core.application.locations.FindAllRegions;
import com.ocity.api.core.application.locations.FindAllSubregions;
import com.ocity.api.core.application.locations.FindCitiesByStateId;
import com.ocity.api.core.application.locations.FindCountriesByRegionId;
import com.ocity.api.core.application.locations.FindCountriesBySubregionId;
import com.ocity.api.core.application.locations.FindStatesByCountryId;
import com.ocity.api.core.application.locations.FindSubregionsByRegionId;
import com.ocity.api.core.application.locations.dto.out.CityDTO;
import com.ocity.api.core.application.locations.dto.out.CountryDTO;
import com.ocity.api.core.application.locations.dto.out.RegionDTO;
import com.ocity.api.core.application.locations.dto.out.StateDTO;
import com.ocity.api.core.application.locations.dto.out.SubregionDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;

@Controller
public class LocationsController {

    private final FindAllRegions findAllRegions;
    private final FindAllSubregions findAllSubregions;
    private final FindSubregionsByRegionId findSubregionsByRegionId;
    private final FindAllCountries findAllCountries;
    private final FindCountriesBySubregionId findCountriesBySubregionId;
    private final FindCountriesByRegionId findCountriesByRegionId;
    private final FindStatesByCountryId findStatesByCountryId;
    private final FindCitiesByStateId findCitiesByStateId;

    @Autowired
    public LocationsController(FindAllRegions findAllRegions,
                               FindAllSubregions findAllSubregions,
                               FindSubregionsByRegionId findSubregionsByRegionId,
                               FindAllCountries findAllCountries,
                               FindCountriesBySubregionId findCountriesBySubregionId,
                               FindCountriesByRegionId findCountriesByRegionId,
                               FindStatesByCountryId findStatesByCountryId,
                               FindCitiesByStateId findCitiesByStateId) {
        this.findAllRegions = findAllRegions;
        this.findAllSubregions = findAllSubregions;
        this.findSubregionsByRegionId = findSubregionsByRegionId;
        this.findAllCountries = findAllCountries;
        this.findCountriesBySubregionId = findCountriesBySubregionId;
        this.findCountriesByRegionId = findCountriesByRegionId;
        this.findStatesByCountryId = findStatesByCountryId;
        this.findCitiesByStateId = findCitiesByStateId;
    }

    @GetMapping("/regions")
    @ResponseBody
    public List<RegionDTO> getAllRegions() {
        return findAllRegions.execute();
    }

    @GetMapping("/regions/{regionId}/subregions")
    @ResponseBody
    public List<SubregionDTO> getSubregionsByRegionId(@PathVariable Integer regionId) {
        return findSubregionsByRegionId.execute(regionId);
    }

    @GetMapping("/subregions")
    @ResponseBody
    public List<SubregionDTO> getAllSubregions() {
        return findAllSubregions.execute();
    }

    @GetMapping("/regions/{regionId}/countries")
    @ResponseBody
    public List<CountryDTO> getCountriesByRegionId(@PathVariable Integer regionId) {
        return findCountriesByRegionId.execute(regionId);
    }

    @GetMapping("/subregions/{subregionId}/countries")
    @ResponseBody
    public List<CountryDTO> getCountriesBySubregionId(@PathVariable Integer subregionId) {
        return findCountriesBySubregionId.execute(subregionId);
    }

    @GetMapping("/countries")
    @ResponseBody
    public List<CountryDTO> getAllCountries() {
        return findAllCountries.execute();
    }

    @GetMapping("/countries/{countryId}/states")
    @ResponseBody
    public List<StateDTO> getStatesByCountryId(@PathVariable Integer countryId) {
        return findStatesByCountryId.execute(countryId);
    }

    @GetMapping("/states/{stateId}/cities")
    @ResponseBody
    public List<CityDTO> getCitiesByStateId(@PathVariable Integer stateId) {
        return findCitiesByStateId.execute(stateId);
    }
}
