package com.ocity.api.core.infrastructure.locations.entity;

import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.Id;
import jakarta.persistence.NamedQueries;
import jakarta.persistence.NamedQuery;
import jakarta.persistence.Table;

import java.util.Date;

@Entity
@Table(name = "countries")
@NamedQueries({
        @NamedQuery(
                name = CountryEntity.FIND_ALL_COUNTRIES,
                query = " SELECT new CountryEntity(c.id, c.name, c.subregionId) " +
                        " FROM CountryEntity c "
        ),
        @NamedQuery(
                name = CountryEntity.FIND_COUNTRIES_BY_SUBREGION_ID,
                query = " SELECT new CountryEntity(c.id, c.name, c.subregionId) " +
                        " FROM CountryEntity c " +
                        " WHERE c.subregionId = :subregionId "
        ),
        @NamedQuery(
                name = CountryEntity.FIND_COUNTRIES_BY_REGION_ID,
                query = " SELECT new CountryEntity(c.id, c.name, c.subregionId) " +
                        " FROM CountryEntity c " +
                        " WHERE c.regionId = :regionId "
        ),
        @NamedQuery(
                name = CountryEntity.FIND_COUNTRIES_IDS_BY_REGION_ID,
                query = " SELECT c.id " +
                        " FROM CountryEntity c " +
                        " WHERE c.regionId = :regionId "
        ),
        @NamedQuery(
                name = CountryEntity.FIND_COUNTRIES_IDS_BY_SUBREGION_ID,
                query = " SELECT c.id " +
                        " FROM CountryEntity c " +
                        " WHERE c.subregionId = :subregionId "
        )
})
public class CountryEntity {

    public static final String FIND_ALL_COUNTRIES = "CountryEntity.FIND_ALL_COUNTRIES";
    public static final String FIND_COUNTRIES_BY_SUBREGION_ID = "CountryEntity.FIND_COUNTRIES_BY_SUBREGION_ID";
    public static final String FIND_COUNTRIES_BY_REGION_ID = "CountryEntity.FIND_COUNTRIES_BY_REGION_ID";
    public static final String FIND_COUNTRIES_IDS_BY_REGION_ID = "CountryEntity.FIND_COUNTRIES_IDS_BY_REGION_ID";
    public static final String FIND_COUNTRIES_IDS_BY_SUBREGION_ID = "CountryEntity.FIND_COUNTRIES_IDS_BY_SUBREGION_ID";

    public CountryEntity() {
    }

    public CountryEntity(Integer id, String name, Integer subregionId) {
        this.id = id;
        this.name = name;
        this.subregionId = subregionId;
    }

    @Id
    private Integer id;

    private String name;

    private String iso3;

    @Column(name = "numeric_code")
    private String countryCode;

    private String iso2;

    private String phoneCode;

    private String capital;

    private String currency;

    @Column(name = "currency_name")
    private String currencyName;

    @Column(name = "currency_symbol")
    private String currencySymbol;

    @Column(name = "native")
    private String nativeName;

    private String region;

    @Column(name = "region_id")
    private Integer regionId;

    private String subregion;

    @Column(name = "subregion_id")
    private Integer subregionId;

    private String nationality;

    private String timezones;

    private String translations;

    private Double latitude;

    private Double longitude;

    private String emoji;

    @Column(name = "emojiu")
    private String emojiU;

    @Column(name = "created_at")
    private Date createdAt;

    @Column(name = "updated_at")
    private Date updatedAt;

    private Boolean flag;

    @Column(name = "wikidataid")
    private String wikiDataId;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getIso3() {
        return iso3;
    }

    public void setIso3(String iso3) {
        this.iso3 = iso3;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getIso2() {
        return iso2;
    }

    public void setIso2(String iso2) {
        this.iso2 = iso2;
    }

    public String getPhoneCode() {
        return phoneCode;
    }

    public void setPhoneCode(String phoneCode) {
        this.phoneCode = phoneCode;
    }

    public String getCapital() {
        return capital;
    }

    public void setCapital(String capital) {
        this.capital = capital;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public String getCurrencyName() {
        return currencyName;
    }

    public void setCurrencyName(String currencyName) {
        this.currencyName = currencyName;
    }

    public String getCurrencySymbol() {
        return currencySymbol;
    }

    public void setCurrencySymbol(String currencySymbol) {
        this.currencySymbol = currencySymbol;
    }

    public String getNativeName() {
        return nativeName;
    }

    public void setNativeName(String nativeName) {
        this.nativeName = nativeName;
    }

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public Integer getRegionId() {
        return regionId;
    }

    public void setRegionId(Integer regionId) {
        this.regionId = regionId;
    }

    public String getSubregion() {
        return subregion;
    }

    public void setSubregion(String subregion) {
        this.subregion = subregion;
    }

    public Integer getSubregionId() {
        return subregionId;
    }

    public void setSubregionId(Integer subregionId) {
        this.subregionId = subregionId;
    }

    public String getNationality() {
        return nationality;
    }

    public void setNationality(String nationality) {
        this.nationality = nationality;
    }

    public String getTimezones() {
        return timezones;
    }

    public void setTimezones(String timezones) {
        this.timezones = timezones;
    }

    public String getTranslations() {
        return translations;
    }

    public void setTranslations(String translations) {
        this.translations = translations;
    }

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }

    public String getEmoji() {
        return emoji;
    }

    public void setEmoji(String emoji) {
        this.emoji = emoji;
    }

    public String getEmojiU() {
        return emojiU;
    }

    public void setEmojiU(String emojiU) {
        this.emojiU = emojiU;
    }

    public Date getCreatedAt() {
        return createdAt;
    }

    public void setCreatedAt(Date createdAt) {
        this.createdAt = createdAt;
    }

    public Date getUpdatedAt() {
        return updatedAt;
    }

    public void setUpdatedAt(Date updatedAt) {
        this.updatedAt = updatedAt;
    }

    public Boolean getFlag() {
        return flag;
    }

    public void setFlag(Boolean flag) {
        this.flag = flag;
    }

    public String getWikiDataId() {
        return wikiDataId;
    }

    public void setWikiDataId(String wikiDataId) {
        this.wikiDataId = wikiDataId;
    }
}
