package com.ocity.api.login.infrastructure;

import com.ocity.api.login.application.LogIn;
import com.ocity.api.login.infrastructure.dto.out.LoginDTO;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseCookie;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseBody;

@CrossOrigin
@Controller
public class LoginController {

    @Value("${application.security.jwt.token.expiration}")
    private long cookieExpiration;

    private final LogIn logIn;

    @Autowired
    public LoginController(LogIn logIn) {
        this.logIn = logIn;
    }

    @PostMapping("/login")
    @ResponseBody
    public ResponseEntity<LoginDTO> login(@RequestBody com.ocity.api.login.infrastructure.dto.in.LoginDTO loginDTO,
                                          HttpServletResponse response) {
        if (loginDTO.password.equals("fail")) return new ResponseEntity<>(HttpStatus.UNAUTHORIZED); //TODO remove mock

        LoginDTO loginResult = logIn.execute(loginDTO.email, loginDTO.password);

        ResponseCookie apiKeyCookie = ResponseCookie.from("apiKey", loginResult.apiKey())
                .httpOnly(true)
                .maxAge(cookieExpiration)
                .path("/")
                .build();

        response.addHeader(HttpHeaders.SET_COOKIE, apiKeyCookie.toString());

        return new ResponseEntity<>(loginResult, HttpStatus.OK);
    }
}
