package com.ocity.api.login.infrastructure;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ocity.api.login.domain.Email;
import com.ocity.api.login.domain.LoginRepository;
import com.ocity.api.login.domain.Password;
import com.ocity.api.login.domain.User;
import com.ocity.api.login.infrastructure.client.LoginClient;
import com.ocity.api.login.infrastructure.client.LoginResponse;
import com.ocity.api.util.JwtUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

@Service
public class LoginRepositoryAdapter implements LoginRepository {

    private static final ObjectMapper objectMapper = new ObjectMapper().disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES);

    private final JwtUtil jwtUtil;
    private final LoginClient loginClient;

    @Autowired
    public LoginRepositoryAdapter(JwtUtil jwtUtil, LoginClient loginClient) {
        this.jwtUtil = jwtUtil;
        this.loginClient = loginClient;
    }

    @Override
    public User manageLogin(final Email email, final Password password) {
        LoginResponse loginResponse = loginClient.executeLogin(email, password);

        User user = objectMapper.convertValue(jwtUtil.getAllClaimsFromToken(loginResponse.token), User.class);

//        boolean userIsSuperAdmin = user.roles.stream()
//                .anyMatch(role -> role.equalsIgnoreCase("SUPERADMIN"));//TODO review equalsIgnoreCase
//
//        if (!userIsSuperAdmin) return new User(); //TODO review response

        Map<String, Object> claims = new HashMap<>();
        claims.put("userId", user.userId);
        claims.put("country", user.country);
        claims.put("roles", user.roles);

        //TODO generate API key from user data / jwt data
        user.apiKey = jwtUtil.generateApiKey(claims, email.value());

        //TODO do not return user, return if user is super admin or not
        //TODO then, in front-end, if it is not super admin redirect to user information page and show API key and swagger (but call after redirection, IMPORTANT)
        //TODO if it is super admin, redirect to super admin page
        return user;
    }
}
