package com.ocity.api.user;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ocity.api.auth.ApiKeyRetriever;
import com.ocity.api.util.JwtUtil;
import jakarta.servlet.http.HttpServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;

import java.util.Optional;

@Controller
public class UserController {

    private static final ObjectMapper objectMapper = new ObjectMapper().disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES);

    private final ApiKeyRetriever apiKeyRetriever;
    private final JwtUtil jwtUtil;

    @Autowired
    public UserController(ApiKeyRetriever apiKeyRetriever, JwtUtil jwtUtil) {
        this.apiKeyRetriever = apiKeyRetriever;
        this.jwtUtil = jwtUtil;
    }

    @GetMapping("/user")
    @PreAuthorize("hasRole('USER')")
    public ResponseEntity<User> getUserInfo(HttpServletRequest request) {
        Optional<String> mayBeApiKey = apiKeyRetriever.execute(request);

        User user = objectMapper.convertValue(jwtUtil.getAllClaimsFromToken(mayBeApiKey.get()), User.class);

        user.apiKey = mayBeApiKey.orElse(null);

        return new ResponseEntity<>(user, HttpStatus.OK);
    }
}
