package com.ocity.api.locations.application.dto.out;

import com.ocity.api.core.application.locations.dto.out.CountryDTO;
import com.ocity.api.core.application.locations.dto.out.CountryDTOMapper;
import com.ocity.api.core.domain.locations.Country;
import com.ocity.api.core.domain.locations.CountryId;
import com.ocity.api.core.domain.locations.Name;
import com.ocity.api.core.domain.locations.SubregionId;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;

class CountryDTOMapperTest {

    private static final int COUNTRY_ID = 1;
    private static final String NAME = "Country";
    private static final int SUBREGION_ID = 1;

    private final CountryDTOMapper countryDTOMapper = new CountryDTOMapper();

    @Test
    void testMap() {
        CountryDTO dto = countryDTOMapper.map(buildCountry());

        assertEquals(COUNTRY_ID, dto.id);
        assertEquals(NAME, dto.name);
        assertEquals(SUBREGION_ID, dto.subregionId);
    }

    @Test
    void testMap_WhenSubregionIdIsNull() {
        CountryDTO dto = countryDTOMapper.map(buildNullSubregionIdCountry());

        assertEquals(COUNTRY_ID, dto.id);
        assertEquals(NAME, dto.name);
        assertNull(dto.subregionId);
    }

    @Test
    void testMap_WhenCountryIsNull() {
        assertNull(countryDTOMapper.map(null));
    }

    private Country buildCountry() {
        return new Country(new CountryId(COUNTRY_ID), new Name(NAME), new SubregionId(SUBREGION_ID));
    }

    private Country buildNullSubregionIdCountry() {
        return new Country(new CountryId(COUNTRY_ID), new Name(NAME), new SubregionId(null));
    }
}