package com.ocity.api.locations.application.dto.out;

import com.ocity.api.core.application.locations.dto.out.SubregionDTO;
import com.ocity.api.core.application.locations.dto.out.SubregionDTOMapper;
import com.ocity.api.core.domain.locations.Name;
import com.ocity.api.core.domain.locations.RegionId;
import com.ocity.api.core.domain.locations.Subregion;
import com.ocity.api.core.domain.locations.SubregionId;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;

class SubregionDTOMapperTest {

    private static final int SUBREGION_ID = 1;
    private static final int REGION_ID = 2;
    private static final String NAME = "Subregion";

    private final com.ocity.api.core.application.locations.dto.out.SubregionDTOMapper SubregionDTOMapper = new SubregionDTOMapper();

    @Test
    void testMap() {
        SubregionDTO dto = SubregionDTOMapper.map(buildSubregion());

        assertEquals(SUBREGION_ID, dto.id);
        assertEquals(NAME, dto.name);
        assertEquals(REGION_ID, dto.regionId);
    }

    @Test
    void testMap_WhenIdIsNull() {
        SubregionDTO dto = SubregionDTOMapper.map(buildNullRegionIdSubregion());

        assertNull(dto.id);
        assertEquals(NAME, dto.name);
        assertEquals(REGION_ID, dto.regionId);
    }

    @Test
    void testMap_WhenSubregionIsNull() {
        assertNull(SubregionDTOMapper.map(null));
    }

    private Subregion buildSubregion() {
        return new Subregion(new SubregionId(SUBREGION_ID), new Name(NAME), new RegionId(REGION_ID));
    }

    private Subregion buildNullRegionIdSubregion() {
        return new Subregion(new SubregionId(null), new Name(NAME), new RegionId(REGION_ID));
    }
    
}